@@ -4,9 +4,8 @@ import hyclib as lib
 
 @lib.clstools.attr_repr
 class SQL(abc.ABC):
-    def __init__(self, db, from_, sql):
+    def __init__(self, db, sql):
         self.db = db
-        self.from_ = from_
         self.sql = sql
 
     def __str__(self):
